@@ -14,7 +14,6 @@ import six
 from manifestparser import TestManifest, combine_fields
 from mozbuild.base import MozbuildObject
 from mozbuild.testing import REFTEST_FLAVORS, TEST_MANIFESTS
-from mozbuild.util import OrderedDefaultDict
 from mozpack.files import FileFinder
 
 here = os.path.abspath(os.path.dirname(__file__))
@@ -100,7 +99,7 @@ TEST_SUITES = {
             "test-verify($|.*(-1|[^0-9])$)",
         ],
     },
-    "mochitest-browser-chrome-screenshots": {
+    "mochitest-browser-screenshots": {
         "aliases": ("ss", "screenshots-chrome"),
         "build_flavor": "browser-chrome",
         "mach_command": "mochitest",
@@ -109,7 +108,7 @@ TEST_SUITES = {
             "subsuite": "screenshots",
             "test_paths": None,
         },
-        "task_regex": ["browser-screenshots($|.*(-1|[^0-9])$)"],
+        "task_regex": ["mochitest-browser-screenshots($|.*(-1|[^0-9])$)"],
     },
     "mochitest-chrome": {
         "aliases": ("mc",),
@@ -405,7 +404,7 @@ _test_subsuites = {
     ("browser-chrome", "devtools"): "mochitest-devtools-chrome",
     ("browser-chrome", "media"): "mochitest-browser-media",
     ("browser-chrome", "remote"): "mochitest-remote",
-    ("browser-chrome", "screenshots"): "mochitest-browser-chrome-screenshots",
+    ("browser-chrome", "screenshots"): "mochitest-browser-screenshots",
     ("chrome", "gpu"): "mochitest-chrome-gpu",
     ("mochitest", "gpu"): "mochitest-plain-gpu",
     ("mochitest", "media"): "mochitest-media",
@@ -612,7 +611,7 @@ class TestResolver(MozbuildObject):
         self._wpt_loaded = False
 
     def _reset_state(self):
-        self._tests_by_path = OrderedDefaultDict(list)
+        self._tests_by_path = defaultdict(list)
         self._tests_by_flavor = defaultdict(set)
         self._tests_by_manifest = defaultdict(list)
         self._test_dirs = set()
@@ -752,7 +751,7 @@ class TestResolver(MozbuildObject):
                 continue
 
             # If the path is a manifest, add all tests defined in that manifest.
-            if any(path.endswith(e) for e in (".ini", ".list")):
+            if any(path.endswith(e) for e in (".toml", ".ini", ".list")):
                 key = "manifest" if os.path.isabs(path) else "manifest_relpath"
                 candidate_paths |= {
                     t["file_relpath"]
@@ -839,13 +838,21 @@ class TestResolver(MozbuildObject):
         if test["name"].startswith("/_mozilla"):
             depth = depth + 1
 
-        # Webdriver BiDi tests are nested in a "bidi" subfolder. Increase the
-        # depth to avoid grouping all bidi tests in one chunk.
+        # Webdriver tests are nested in "classic" and "bidi" folders. Increase
+        # the depth to avoid grouping all classic or bidi tests in one chunk.
+        if test["name"].startswith(("/webdriver", "/_mozilla/webdriver")):
+            depth = depth + 1
+
+        # Webdriver BiDi tests are nested even further as tests are grouped by
+        # module but also by command / event name.
         if test["name"].startswith(
             ("/webdriver/tests/bidi", "/_mozilla/webdriver/bidi")
         ):
             depth = depth + 1
 
+        if test["name"].startswith("/_mozilla/webgpu"):
+            depth = 9001
+
         group = os.path.dirname(test["name"])
         while group.count("/") > depth:
             group = os.path.dirname(group)
@@ -879,7 +886,6 @@ class TestResolver(MozbuildObject):
             self.topsrcdir,
             self.topobjdir,
             rebuild=False,
-            download=True,
             config_path=None,
             rewrite_config=True,
             update=True,
