@@ -4,6 +4,7 @@ var gLonghandProperties = [
 	{ name: "align-self", prop: "alignSelf" },
 	{ name: "aspect-ratio", prop: "aspectRatio" },
 	{ name: "backface-visibility", prop: "backfaceVisibility" },
+	{ name: "baseline-source", prop: "baselineSource" },
 	{ name: "border-collapse", prop: "borderCollapse" },
 	{ name: "border-image-repeat", prop: "borderImageRepeat" },
 	{ name: "box-decoration-break", prop: "boxDecorationBreak" },
@@ -54,8 +55,8 @@ var gLonghandProperties = [
 	{ name: "list-style-position", prop: "listStylePosition" },
 	{ name: "mask-type", prop: "maskType" },
 	{ name: "masonry-auto-flow", prop: "masonryAutoFlow", pref: "layout.css.grid-template-masonry-value.enabled" },
-	{ name: "math-depth", prop: "mathDepth", pref: "layout.css.math-depth.enabled" },
-	{ name: "math-style", prop: "mathStyle", pref: "layout.css.math-style.enabled" },
+	{ name: "math-depth", prop: "mathDepth" },
+	{ name: "math-style", prop: "mathStyle" },
 	{ name: "mix-blend-mode", prop: "mixBlendMode" },
 	{ name: "-moz-box-align", prop: "MozBoxAlign" },
 	{ name: "-moz-box-direction", prop: "MozBoxDirection" },
@@ -66,12 +67,11 @@ var gLonghandProperties = [
 	{ name: "-moz-orient", prop: "MozOrient" },
 	{ name: "-moz-osx-font-smoothing", prop: "MozOsxFontSmoothing", pref: "layout.css.osx-font-smoothing.enabled" },
 	{ name: "-moz-text-size-adjust", prop: "MozTextSizeAdjust" },
-	{ name: "-moz-user-focus", prop: "MozUserFocus" },
 	{ name: "-moz-user-input", prop: "MozUserInput" },
 	{ name: "-moz-user-modify", prop: "MozUserModify" },
 	{ name: "-moz-window-dragging", prop: "MozWindowDragging" },
 	{ name: "object-fit", prop: "objectFit" },
-	{ name: "offset-rotate", prop: "offsetRotate", pref: "layout.css.motion-path.enabled" },
+	{ name: "offset-rotate", prop: "offsetRotate" },
 	{ name: "outline-style", prop: "outlineStyle" },
 	{ name: "overflow-anchor", prop: "overflowAnchor", pref: "layout.css.scroll-anchoring.enabled" },
 	{ name: "overflow-wrap", prop: "overflowWrap" },
@@ -86,7 +86,7 @@ var gLonghandProperties = [
 	{ name: "scroll-snap-align", prop: "scrollSnapAlign" },
 	{ name: "scroll-snap-stop", prop: "scrollSnapStop" },
 	{ name: "scroll-snap-type", prop: "scrollSnapType" },
-	{ name: "scrollbar-gutter", prop: "scrollbarGutter", pref: "layout.css.scrollbar-gutter.enabled" },
+	{ name: "scrollbar-gutter", prop: "scrollbarGutter" },
 	{ name: "scrollbar-width", prop: "scrollbarWidth" },
 	{ name: "shape-rendering", prop: "shapeRendering" },
 	{ name: "stroke-linecap", prop: "strokeLinecap" },
@@ -105,6 +105,8 @@ var gLonghandProperties = [
 	{ name: "text-rendering", prop: "textRendering" },
 	{ name: "text-transform", prop: "textTransform" },
 	{ name: "text-underline-position", prop: "textUnderlinePosition" },
+	{ name: "text-wrap-mode", prop: "textWrapMode" },
+	{ name: "text-wrap-style", prop: "textWrapStyle", pref: "layout.css.text-wrap-balance.enabled" },
 	{ name: "touch-action", prop: "touchAction" },
 	{ name: "transform-box", prop: "transformBox" },
 	{ name: "transform-style", prop: "transformStyle" },
@@ -114,10 +116,11 @@ var gLonghandProperties = [
 	{ name: "visibility", prop: "visibility" },
 	{ name: "-webkit-line-clamp", prop: "webkitLineClamp" },
 	{ name: "-webkit-text-security", prop: "webkitTextSecurity" },
-	{ name: "white-space", prop: "whiteSpace" },
+	{ name: "white-space-collapse", prop: "whiteSpaceCollapse" },
 	{ name: "word-break", prop: "wordBreak" },
 	{ name: "writing-mode", prop: "writingMode" },
 	{ name: "z-index", prop: "zIndex" },
+	{ name: "zoom", prop: "zoom", pref: "layout.css.zoom.enabled" },
 	{ name: "appearance", prop: "appearance" },
 	{ name: "-moz-force-broken-image-icon", prop: "MozForceBrokenImageIcon" },
 	{ name: "break-after", prop: "breakAfter" },
@@ -128,17 +131,18 @@ var gLonghandProperties = [
 	{ name: "overflow-clip-box-inline", prop: "overflowClipBoxInline", pref: "layout.css.overflow-clip-box.enabled" },
 	{ name: "fill-opacity", prop: "fillOpacity" },
 	{ name: "stroke-opacity", prop: "strokeOpacity" },
+	{ name: "-moz-box-ordinal-group", prop: "MozBoxOrdinalGroup" },
+	{ name: "order", prop: "order" },
+	{ name: "font-synthesis-position", prop: "fontSynthesisPosition" },
 	{ name: "font-synthesis-small-caps", prop: "fontSynthesisSmallCaps" },
 	{ name: "font-synthesis-style", prop: "fontSynthesisStyle" },
 	{ name: "font-synthesis-weight", prop: "fontSynthesisWeight" },
-	{ name: "-moz-box-ordinal-group", prop: "MozBoxOrdinalGroup" },
-	{ name: "order", prop: "order" },
 	{ name: "flex-grow", prop: "flexGrow" },
 	{ name: "flex-shrink", prop: "flexShrink" },
 	{ name: "-moz-box-flex", prop: "MozBoxFlex" },
 	{ name: "stroke-miterlimit", prop: "strokeMiterlimit" },
-	{ name: "overflow-block", prop: "overflowBlock", pref: "layout.css.overflow-logical.enabled" },
-	{ name: "overflow-inline", prop: "overflowInline", pref: "layout.css.overflow-logical.enabled" },
+	{ name: "overflow-block", prop: "overflowBlock" },
+	{ name: "overflow-inline", prop: "overflowInline" },
 	{ name: "overflow-x", prop: "overflowX" },
 	{ name: "overflow-y", prop: "overflowY" },
 	{ name: "overscroll-behavior-block", prop: "overscrollBehaviorBlock", pref: "layout.css.overscroll-behavior.enabled" },
@@ -158,7 +162,7 @@ var gLonghandProperties = [
 	{ name: "border-right-style", prop: "borderRightStyle" },
 	{ name: "border-top-style", prop: "borderTopStyle" },
 	{ name: "column-rule-style", prop: "columnRuleStyle" },
-	{ name: "accent-color", prop: "accentColor", pref: "layout.css.accent-color.enabled" },
+	{ name: "accent-color", prop: "accentColor" },
 	{ name: "align-tracks", prop: "alignTracks", pref: "layout.css.grid-template-masonry-value.enabled" },
 	{ name: "animation-composition", prop: "animationComposition", pref: "layout.css.animation-composition.enabled" },
 	{ name: "animation-delay", prop: "animationDelay" },
@@ -189,7 +193,7 @@ var gLonghandProperties = [
 	{ name: "clip", prop: "clip" },
 	{ name: "clip-path", prop: "clipPath" },
 	{ name: "color", prop: "color" },
-	{ name: "color-scheme", prop: "colorScheme", pref: "layout.css.color-scheme.enabled" },
+	{ name: "color-scheme", prop: "colorScheme" },
 	{ name: "column-width", prop: "columnWidth" },
 	{ name: "container-name", prop: "containerName", pref: "layout.css.container-queries.enabled" },
 	{ name: "content", prop: "content" },
@@ -207,7 +211,7 @@ var gLonghandProperties = [
 	{ name: "font-variant-alternates", prop: "fontVariantAlternates" },
 	{ name: "font-variation-settings", prop: "fontVariationSettings", pref: "layout.css.font-variations.enabled" },
 	{ name: "grid-template-areas", prop: "gridTemplateAreas" },
-	{ name: "hyphenate-character", prop: "hyphenateCharacter", pref: "layout.css.hyphenate-character.enabled" },
+	{ name: "hyphenate-character", prop: "hyphenateCharacter" },
 	{ name: "justify-tracks", prop: "justifyTracks", pref: "layout.css.grid-template-masonry-value.enabled" },
 	{ name: "letter-spacing", prop: "letterSpacing" },
 	{ name: "line-height", prop: "lineHeight" },
@@ -222,8 +226,10 @@ var gLonghandProperties = [
 	{ name: "mask-repeat", prop: "maskRepeat" },
 	{ name: "mask-size", prop: "maskSize" },
 	{ name: "-moz-context-properties", prop: "MozContextProperties", pref: "svg.context-properties.content.enabled" },
-	{ name: "offset-path", prop: "offsetPath", pref: "layout.css.motion-path.enabled" },
-	{ name: "page", prop: "page", pref: "layout.css.named-pages.enabled" },
+	{ name: "offset-anchor", prop: "offsetAnchor" },
+	{ name: "offset-path", prop: "offsetPath" },
+	{ name: "offset-position", prop: "offsetPosition" },
+	{ name: "page", prop: "page" },
 	{ name: "perspective", prop: "perspective" },
 	{ name: "quotes", prop: "quotes" },
 	{ name: "rotate", prop: "rotate", pref: "layout.css.individual-transform.enabled" },
@@ -238,8 +244,10 @@ var gLonghandProperties = [
 	{ name: "tab-size", prop: "tabSize" },
 	{ name: "text-decoration-thickness", prop: "textDecorationThickness" },
 	{ name: "text-emphasis-style", prop: "textEmphasisStyle" },
+	{ name: "text-indent", prop: "textIndent" },
 	{ name: "text-overflow", prop: "textOverflow" },
 	{ name: "text-shadow", prop: "textShadow" },
+	{ name: "transition-behavior", prop: "transitionBehavior", pref: "layout.css.transition-behavior.enabled" },
 	{ name: "transition-delay", prop: "transitionDelay" },
 	{ name: "transition-duration", prop: "transitionDuration" },
 	{ name: "transition-property", prop: "transitionProperty" },
@@ -249,12 +257,11 @@ var gLonghandProperties = [
 	{ name: "view-timeline-axis", prop: "viewTimelineAxis", pref: "layout.css.scroll-driven-animations.enabled" },
 	{ name: "view-timeline-inset", prop: "viewTimelineInset", pref: "layout.css.scroll-driven-animations.enabled" },
 	{ name: "view-timeline-name", prop: "viewTimelineName", pref: "layout.css.scroll-driven-animations.enabled" },
+	{ name: "-webkit-text-stroke-width", prop: "webkitTextStrokeWidth" },
 	{ name: "will-change", prop: "willChange" },
 	{ name: "word-spacing", prop: "wordSpacing" },
 	{ name: "object-position", prop: "objectPosition" },
 	{ name: "perspective-origin", prop: "perspectiveOrigin" },
-	{ name: "offset-anchor", prop: "offsetAnchor", pref: "layout.css.motion-path.enabled" },
-	{ name: "offset-position", prop: "offsetPosition", pref: "layout.css.motion-path-offset-position.enabled" },
 	{ name: "fill", prop: "fill" },
 	{ name: "stroke", prop: "stroke" },
 	{ name: "transform-origin", prop: "transformOrigin" },
@@ -284,8 +291,7 @@ var gLonghandProperties = [
 	{ name: "max-width", prop: "maxWidth" },
 	{ name: "cx", prop: "cx" },
 	{ name: "cy", prop: "cy" },
-	{ name: "offset-distance", prop: "offsetDistance", pref: "layout.css.motion-path.enabled" },
-	{ name: "text-indent", prop: "textIndent" },
+	{ name: "offset-distance", prop: "offsetDistance" },
 	{ name: "x", prop: "x" },
 	{ name: "y", prop: "y" },
 	{ name: "border-bottom-left-radius", prop: "borderBottomLeftRadius" },
@@ -304,6 +310,16 @@ var gLonghandProperties = [
 	{ name: "min-inline-size", prop: "minInlineSize" },
 	{ name: "min-width", prop: "minWidth" },
 	{ name: "width", prop: "width" },
+	{ name: "border-block-end-width", prop: "borderBlockEndWidth" },
+	{ name: "border-block-start-width", prop: "borderBlockStartWidth" },
+	{ name: "border-bottom-width", prop: "borderBottomWidth" },
+	{ name: "border-inline-end-width", prop: "borderInlineEndWidth" },
+	{ name: "border-inline-start-width", prop: "borderInlineStartWidth" },
+	{ name: "border-left-width", prop: "borderLeftWidth" },
+	{ name: "border-right-width", prop: "borderRightWidth" },
+	{ name: "border-top-width", prop: "borderTopWidth" },
+	{ name: "column-rule-width", prop: "columnRuleWidth" },
+	{ name: "outline-width", prop: "outlineWidth" },
 	{ name: "padding-block-end", prop: "paddingBlockEnd" },
 	{ name: "padding-block-start", prop: "paddingBlockStart" },
 	{ name: "padding-bottom", prop: "paddingBottom" },
@@ -324,17 +340,6 @@ var gLonghandProperties = [
 	{ name: "scroll-padding-left", prop: "scrollPaddingLeft" },
 	{ name: "scroll-padding-right", prop: "scrollPaddingRight" },
 	{ name: "scroll-padding-top", prop: "scrollPaddingTop" },
-	{ name: "border-block-end-width", prop: "borderBlockEndWidth" },
-	{ name: "border-block-start-width", prop: "borderBlockStartWidth" },
-	{ name: "border-bottom-width", prop: "borderBottomWidth" },
-	{ name: "border-inline-end-width", prop: "borderInlineEndWidth" },
-	{ name: "border-inline-start-width", prop: "borderInlineStartWidth" },
-	{ name: "border-left-width", prop: "borderLeftWidth" },
-	{ name: "border-right-width", prop: "borderRightWidth" },
-	{ name: "border-top-width", prop: "borderTopWidth" },
-	{ name: "column-rule-width", prop: "columnRuleWidth" },
-	{ name: "outline-width", prop: "outlineWidth" },
-	{ name: "-webkit-text-stroke-width", prop: "webkitTextStrokeWidth" },
 	{ name: "outline-offset", prop: "outlineOffset" },
 	{ name: "overflow-clip-margin", prop: "overflowClipMargin" },
 	{ name: "scroll-margin-block-end", prop: "scrollMarginBlockEnd" },
@@ -414,8 +419,7 @@ var gShorthandProperties = [
 	{ name: "page-break-before", prop: "pageBreakBefore" },
 	{ name: "page-break-after", prop: "pageBreakAfter" },
 	{ name: "page-break-inside", prop: "pageBreakInside" },
-	{ name: "offset", prop: "offset", pref: "layout.css.motion-path.enabled" },
-	{ name: "zoom", prop: "zoom", pref: "layout.css.zoom-transform-hack.enabled" },
+	{ name: "offset", prop: "offset" },
 	{ name: "columns", prop: "columns" },
 	{ name: "column-rule", prop: "columnRule" },
 	{ name: "font", prop: "font" },
@@ -423,6 +427,8 @@ var gShorthandProperties = [
 	{ name: "font-synthesis", prop: "fontSynthesis" },
 	{ name: "marker", prop: "marker" },
 	{ name: "text-emphasis", prop: "textEmphasis" },
+	{ name: "text-wrap", prop: "textWrap" },
+	{ name: "white-space", prop: "whiteSpace" },
 	{ name: "-webkit-text-stroke", prop: "webkitTextStroke" },
 	{ name: "list-style", prop: "listStyle" },
 	{ name: "margin", prop: "margin" },
